# -*- coding: utf-8 -*-

import pyxb.bundles.reqif.driver
import pyxb.bundles.reqif.ReqIF as ReqIF

xml = open('in.xml').read();
doc = ReqIF.CreateFromDocument(xml)
print(doc.THE_HEADER.REQ_IF_HEADER.COMMENT)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import logging
import pyxb.binding.generate
import pyxb.utils.domutils
import xml.dom.minidom as dom


if __name__ == '__main__':
    logging.basicConfig()
_log = logging.getLogger(__name__)

xsd = '''<?xml version="1.0" encoding="UTF-8"?>
<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
  <xs:element name="HOST">
    <xs:complexType>
      <xs:sequence>
        <xs:element name="ID" type="xs:integer"/>
        <xs:element name="TEMPLATE" type="xs:anyType"/>
      </xs:sequence>
    </xs:complexType>
  </xs:element>
</xs:schema>
'''

code = pyxb.binding.generate.GeneratePython(schema_text=xsd)

rv = compile(code, 'test', 'exec')
eval(rv)

import unittest

class TestIssue0092 (unittest.TestCase):
    def testCreateEmptyTemplate (self):
        xmlt = '<HOST><ID>1</ID><TEMPLATE/></HOST>';
        xmld = xmlt.encode('utf-8');
        doc = CreateFromDocument(xmld);
        self.assertEqual(doc.ID,1)

    def testCreateToDom (self):
        xmlt = '<HOST><ID>1</ID><TEMPLATE><NODE>1</NODE></TEMPLATE></HOST>';
        xmld = xmlt.encode('utf-8');
        doc = CreateFromDocument(xmld);
        templateFragment=doc.TEMPLATE.toDOM()
        self.assertEqual(templateFragment.toxml(), '''<?xml version="1.0" ?><TEMPLATE><NODE>1</NODE></TEMPLATE>''')

    def testCreateWithCDATAToDom (self):
        xmlt = '<HOST><ID>1</ID><TEMPLATE><NODE><![CDATA[text]]></NODE></TEMPLATE></HOST>';
        xmld = xmlt.encode('utf-8');
        doc = CreateFromDocument(xmld);
        templateFragment=doc.TEMPLATE.toDOM()
        self.assertEqual(templateFragment.toxml(), '''<?xml version="1.0" ?><TEMPLATE><NODE>text</NODE></TEMPLATE>''')

    def testCreateFromDOMWithCDATAToDom (self):
        xmlt = '<HOST><ID>1</ID><TEMPLATE><NODE><![CDATA[text]]></NODE></TEMPLATE></HOST>';
        xmld = xmlt.encode('utf-8');
        domDoc=dom.parseString(xmld);
        doc = CreateFromDOM(domDoc);
        templateFragment=doc.TEMPLATE.toDOM()
        self.assertEqual(templateFragment.toxml(), '''<?xml version="1.0" ?><TEMPLATE><NODE>text</NODE></TEMPLATE>''')


if __name__ == '__main__':
    unittest.main()



import trac193
import pyxb.binding.datatypes as xs

bdv = trac193.Money._UseForTag('Value').elementBinding().typeDefinition()
assert bdv == xs.integer
assert trac193.Money._UseForTag('Currency').elementBinding().typeDefinition() == xs.anySimpleType
assert trac193.Money._UseForTag('Season').elementBinding().typeDefinition() == xs.anyType

rdv = trac193.OpenDeliveries._UseForTag('Value').elementBinding().typeDefinition()
assert rdv == trac193.Value
assert trac193.OpenDeliveries._UseForTag('Currency').elementBinding().typeDefinition() == trac193.Currency
assert trac193.OpenDeliveries._UseForTag('Season').elementBinding().typeDefinition() == trac193.Season

assert xs.integer != trac193.Value
assert xs.anySimpleType != trac193.Currency
assert xs.anyType != trac193.Season

# In fact something that refines xs.int (Python int) is not a subclass
# of xs.integer (Python long).  This is a flaw in PyXB's data type
# hierarchy which can't be easily fixed, so ignore it.
assert not issubclass(rdv, bdv)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import logging
if __name__ == '__main__':
    logging.basicConfig()
_log = logging.getLogger(__name__)
import pyxb.binding.generate
import pyxb.utils.domutils
import pyxb.binding.datatypes as xs
import datetime;
from xml.dom import Node

import os.path
xsd='''<?xml version="1.0" encoding="utf-8"?>
<xs:schema targetNamespace="urn:issue-0066" elementFormDefault="qualified" xmlns:xs="http://www.w3.org/2001/XMLSchema">
  <xs:element name="elt" type="xs:int"/>
</xs:schema>
'''

code = pyxb.binding.generate.GeneratePython(schema_text=xsd)
#open('code.py', 'w').write(code)
#print code

rv = compile(code, 'test', 'exec')
eval(rv)

from pyxb.exceptions_ import *

import unittest

class TestIssue0066 (unittest.TestCase):
    def test (self):
        instance = elt(4);
        xmlt = '<ns1:elt xmlns:ns1="urn:issue-0066">4</ns1:elt>';
        xmld = xmlt.encode('utf-8');
        self.assertEqual(instance.toxml('utf-8', root_only=True), xmld);
        self.assertRaises(UsageError, Namespace.setPrefix, '');

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
import logging
if __name__ == '__main__':
    logging.basicConfig()
_log = logging.getLogger(__name__)
import pyxb.binding.generate
import pyxb.utils.domutils
from xml.dom import Node

import os.path
xsd='''<?xml version="1.0" encoding="UTF-8"?>
<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
  <xs:element name="di" default="32" type="xs:int"/>
  <xs:element name="fi" fixed="21" type="xs:int"/>
  <xs:element name="cfi">
    <xs:complexType>
      <xs:simpleContent>
        <xs:extension base="xs:int"/>
      </xs:simpleContent>
    </xs:complexType>
  </xs:element>
  <xs:element name="cdi">
    <xs:complexType>
      <xs:simpleContent>
        <xs:extension base="xs:int"/>
      </xs:simpleContent>
    </xs:complexType>
  </xs:element>
</xs:schema>'''

code = pyxb.binding.generate.GeneratePython(schema_text=xsd)
#open('code.py', 'w').write(code)

rv = compile(code, 'test', 'exec')
eval(rv)

from pyxb.exceptions_ import *

import unittest
import sys

class TestIssue0073 (unittest.TestCase):
    def testDefault (self):
        xmlt = six.u('<di/>');
        self.assertEqual(CreateFromDocument(xmlt), 32)
        xmlt = six.u('<di>32</di>');
        self.assertEqual(CreateFromDocument(xmlt), 32)
        xmlt = six.u('<cdi>32</cdi>');
        self.assertEqual(CreateFromDocument(xmlt).value(), 32)

    def testFixed (self):
        xmlt = six.u('<fi/>');
        self.assertEqual(CreateFromDocument(xmlt), 21)
        xmlt = six.u('<fi>21</fi>');
        self.assertEqual(CreateFromDocument(xmlt), 21)
        xmlt = six.u('<cfi>21</cfi>');
        self.assertEqual(CreateFromDocument(xmlt).value(), 21)

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import logging
if __name__ == '__main__':
    logging.basicConfig()
_log = logging.getLogger(__name__)
import pyxb.binding.generate
import pyxb.utils.domutils
from xml.dom import Node

import os.path
xsd='''<?xml version="1.0" encoding="utf-8"?>
<xs:schema elementFormDefault="qualified" xmlns:xs="http://www.w3.org/2001/XMLSchema">
  <xs:element name="Address">
    <xs:complexType>
      <xs:sequence>
        <xs:element name="City" type="xs:string" />
        <xs:element name="Country" minOccurs="0">
          <xs:simpleType>
            <xs:restriction base="xs:string">
              <xs:pattern value="[A-Z]{2}|" />
            </xs:restriction>
          </xs:simpleType>
        </xs:element>
      </xs:sequence>
    </xs:complexType>
  </xs:element>
</xs:schema>
'''

code = pyxb.binding.generate.GeneratePython(schema_text=xsd)
#open('code.py', 'w').write(code)
#print code

rv = compile(code, 'test', 'exec')
eval(rv)

from pyxb.exceptions_ import *

import unittest

class TestIssue0069 (unittest.TestCase):
    def testCountry (self):
        address = Address()
        address.City = 'New-York'
        with self.assertRaises(SimpleFacetValueError) as cm:
            address.Country = 'USA'
        address.Country = 'US'
        xmlt = '<Address><City>New-York</City><Country>US</Country></Address>';
        xmld = xmlt.encode('utf-8');
        self.assertEqual(address.toxml('utf8', root_only=True), xmld)

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright 2009-2017, Peter A. Bigot
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain a
# copy of the License at:
#
#            http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from __future__ import print_function
import os.path
from docutils import nodes
import sys
import re

__Reference_re = re.compile('\s*(.*)\s+<(.*)>\s*$', re.MULTILINE + re.DOTALL)

def ticket_role(role, rawtext, text, lineno, inliner, options={}, content=[]):
    """
    Role `:ticket:` generates references to SourceForge tickets.
    """
    trac_root = 'https://sourceforge.net/p/pyxb/tickets'

    # assume module is references

    #print 'Text "%s"' % (text,)
    mo = __Reference_re.match(text)
    label = None
    if mo is not None:
        ( label, text ) = mo.group(1, 2)
    ticket = text.strip()

    uri = '%s/%s/' % (trac_root, ticket)
    if label is None:
        label = 'SF ticket %s' % (ticket,)
    node = nodes.reference(rawtext, label, refuri=uri, **options)

    return [node], []

def issue_role(role, rawtext, text, lineno, inliner, options={}, content=[]):
    """
    Role `:issue:` generates references to github issues.
    """
    issue_root = 'https://github.com/pabigot/pyxb/issues'

    # assume module is references

    mo = __Reference_re.match(text)
    label = None
    if mo is not None:
        ( label, text ) = mo.group(1, 2)
    ticket = text.strip()

    uri = '%s/%s/' % (issue_root, ticket)
    if label is None:
        label = 'issue %s' % (ticket,)
    node = nodes.reference(rawtext, label, refuri=uri, **options)

    return [node], []

def setup(app):
    app.add_role('ticket', ticket_role)
    app.add_role('issue', issue_role)



# Bring everything in
from raw.ipo import *
from pyxb.utils import six

# Provide a way to reference the raw bindings that we're going to override
import raw.ipo as raw_ipo

@six.python_2_unicode_compatible
class USAddress (raw_ipo.USAddress):
    def __str__ (self):
        return six.u('''%s
%s
%s %s, %s''') % (self.name, self.street, self.city, self.state, self.zip)
    pass
raw_ipo.USAddress._SetSupersedingClass(USAddress)



# -*- coding: utf-8 -*-

from __future__ import print_function
import sys
import dict
from pyxb.utils.six.moves.urllib.request import urlopen
import pyxb.utils.domutils as domutils
from xml.dom import minidom

# Get the list of dictionaries available from the service.
port_uri = 'http://services.aonaware.com/DictService/DictService.asmx'
uri = port_uri + '/DictionaryList'
dle_xml = urlopen(uri).read()
dle_dom = domutils.StringToDOM(dle_xml)
dle = dict.ArrayOfDictionary.createFromDOM(dle_dom)

op_path = '/DictionaryInfo'
for d in dle.Dictionary:
    # Create a REST-style query to retrieve the information about this dictionary.
    uri = '%s%s?dictId=%s' % (port_uri, op_path, d.Id)
    resp = urlopen(uri).read()
    print("%s (%s) : %d chars" % (d.Name, d.Id, len(resp)));

    # The response is a simple type derived from string, so we can
    # just extract and print it.  Excluded by default since it has
    # leading and trailing whitespace that causes problems with using
    # git to store the expected output.
    di_resp = dict.CreateFromDOM(domutils.StringToDOM(resp))
    if sys.stdout.isatty():
        print("%s\n" % di_resp);



# -*- coding: utf-8 -*-
import logging
if __name__ == '__main__':
    logging.basicConfig()
_log = logging.getLogger(__name__)
import unittest
import pyxb.binding.datatypes as xsd

class Test_anySimpleType (unittest.TestCase):
    def testRange (self):
        self.fail("Datatype anySimpleType test not implemented")

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import logging
if __name__ == '__main__':
    logging.basicConfig()
_log = logging.getLogger(__name__)
import pyxb.binding.generate
import pyxb.utils.domutils
from xml.dom import Node

import os.path
xsd='''<?xml version="1.0" encoding="UTF-8"?>
<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
  <xs:simpleType name="tla">
    <xs:restriction base="xs:string">
      <xs:length value="3"/>
    </xs:restriction>
  </xs:simpleType>
  <xs:element name="tla" type="tla"/>
  <xs:simpleType name="lctla">
    <xs:restriction base="tla">
      <xs:length value="3"/>
      <xs:pattern value="\p{Ll}*"/>
    </xs:restriction>
  </xs:simpleType>
  <xs:element name="lctla" type="lctla"/>
  <xs:complexType name="env">
    <xs:sequence>
      <xs:element name="tla" type="tla" minOccurs="0"/>
    </xs:sequence>
  </xs:complexType>
  <xs:element name="env" type="env"/>
  <xs:complexType name="lcenv">
    <xs:complexContent>
      <xs:restriction base="env">
        <xs:sequence>
          <xs:element name="tla" type="lctla" minOccurs="0"/>
        </xs:sequence>
      </xs:restriction>
    </xs:complexContent>
  </xs:complexType>
  <xs:element name="lcenv" type="lcenv"/>
</xs:schema>'''

code = pyxb.binding.generate.GeneratePython(schema_text=xsd)
#open('code.py', 'w').write(code)

rv = compile(code, 'test', 'exec')
eval(rv)

from pyxb.exceptions_ import *

import unittest
import sys

class TestIssue0078 (unittest.TestCase):
    def testInheritance (self):
        self.assertTrue(issubclass(lctla_, tla_))
        self.assertTrue(issubclass(lcenv_, env_))

    def testSimpleTypes (self):
        self.assertEqual('FOO', tla('FOO'))
        self.assertEqual('foo', lctla('foo'))
        self.assertRaises(SimpleFacetValueError, lctla, 'FOO');

    def testBase (self):
        instance = env();
        instance.tla = 'FOO';
        xmlt = '<env><tla>FOO</tla></env>';
        xmld = xmlt.encode('utf-8');
        self.assertEqual(instance.toxml('utf-8', root_only=True), xmld);

    def testRestr (self):
        instance = lcenv();
        instance.tla = 'foo';
        xmlt = '<lcenv><tla>foo</tla></lcenv>';
        xmld = xmlt.encode('utf-8');
        self.assertEqual(instance.toxml('utf-8', root_only=True), xmld)

    def testRestrValidation (self):
        instance = lcenv();
        with self.assertRaises(SimpleFacetValueError) as cm:
            instance.tla = 'FOO';
        self.assertTrue(isinstance(cm.exception, SimpleFacetValueError))

if __name__ == '__main__':
    unittest.main()



from __future__ import print_function
import pyxb
import ipo
import xml.dom.minidom
import time
import io

xmld = open('ipo.xml', 'rb').read()

order = ipo.CreateFromDOM(xml.dom.minidom.parse(io.BytesIO(xmld)).documentElement)

print('%s is sending %s %d thing(s):' % (order.billTo.name, order.shipTo.name, len(order.items.item)))
for item in order.items.item:
    print('  Quantity %d of %s at $%s' % (item.quantity, item.productName, item.USPrice))

# Give Mary more
try:
    item.quantity = 100;
except pyxb.SimpleTypeValueError as e:
    print('Too many: %s' % (e,))
    item.quantity = 10;
print('Increased quantity to %d' % (item.quantity,))



# -*- coding: utf-8 -*-
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain a
# copy of the License at:
#
#            http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

"""Functions used for testing"""

from unittest import TestCase

from .domutils import StringToDOM


class XmlTestCase(TestCase):
    def __init__(self, *args, **kw):
        super().__init__(*args, **kw)
        self.addTypeEqualityFunc(bytes, 'assertBytesEqual')

    def assertBytesEqual(self, first, second, msg=None):
        if first == second:
            return
        if first.startswith(b"<") and second.startswith(b"<"):
            # assume XML documents
            try:
                fd = StringToDOM(first)
                sd = StringToDOM(second)
            except Exception: pass
            else:
                self.assertDOMEqual(fd, sd, msg)
                return
        self._baseAssertEqual(first, second, msg)

    def assertDOMEqual(self, d1, d2, msg=None):
        """assert DOMs *d1* and *d2* are equivalent."""

        def fail(txt):
            raise self.failureException(msg or txt)

        def node_name(n):
            return (f"{{{n.namespaceURI}}}" if n.namespaceURI else "") + f"{n.localName}"

        def eq_element(e1, e2, path):
            """assert elements *e1* and *e2* at *path* are equivalent."""
            t1 = node_name(e1)
            t2 = node_name(e2)
            if t1 != t2:
                fail(f"different elements {t1}/{t2} at {path}")
            path += "/" + t1
            a1 = {node_name(a): a.value for a in e1.attributes}
            a2 = {node_name(a): a.value for a in e2.attributes}
            if a1 != a2:
                fail(f"different attributes {a1}/{a2} at {path}")
            c1 = e1.childNodes
            c2 = e2.childNodes
            if len(c1) != len(c2):
                fail(f"different child numbers {len(c1)}/{len(c2)} at {path}")
            for i in range(len(c1)):
                n1 = c1[i]; n2 = c2[i]
                if n1.nodeType != n2.nodeType:
                    fail(f"different type for child {i} at {path}")
                disp[n1.nodeType](n1, n2, path + f"[{i}]")

        def eq_value(e1, e2, path):
            if e1.value != e2.value:
                fail(f"different value `{e1.value}`/`{e2.value}` at {path}")

        disp = {1: eq_element,
                3: eq_value,
                # maybe more to come
                }

        eq_element(d1.documentElement, d2.documentElement, "")



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import logging
if __name__ == '__main__':
    logging.basicConfig()
_log = logging.getLogger(__name__)
import pyxb.binding.generate
import pyxb.utils.domutils
from xml.dom import Node

import os.path
xsd='''<?xml version="1.0" encoding="UTF-8"?>
<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
  <xs:complexType name="Present">
    <xs:sequence>
      <xs:element name="pContent" minOccurs="1" maxOccurs="1"/>
    </xs:sequence>
  </xs:complexType>
  <xs:complexType name="Optional">
    <xs:sequence>
      <xs:element name="oContent" minOccurs="0" maxOccurs="1"/>
    </xs:sequence>
  </xs:complexType>
  <xs:complexType name="Absent">
    <xs:sequence>
      <xs:element name="aContent" minOccurs="0" maxOccurs="0"/>
    </xs:sequence>
  </xs:complexType>
  <xs:element name="sel">
    <xs:complexType>
      <xs:choice maxOccurs="unbounded">
        <xs:element name="present" type="Present"/>
        <xs:element name="optional" type="Optional"/>
        <xs:element name="absent" type="Absent"/>
      </xs:choice>
    </xs:complexType>
  </xs:element>
</xs:schema>'''

code = pyxb.binding.generate.GeneratePython(schema_text=xsd)
#open('code.py', 'w').write(code)

rv = compile(code, 'test', 'exec')
eval(rv)

from pyxb.exceptions_ import *

import unittest
import sys

class TestIssue0079 (unittest.TestCase):
    def testPresent (self):
        xmlt = '<sel><present><pContent/></present></sel>';
        xmld = xmlt.encode('utf-8');
        doc = CreateFromDocument(xmlt);
        self.assertEqual(xmld, doc.toxml('utf-8', root_only=True))

    def testOptional (self):
        xmlt = '<sel><optional><oContent/></optional></sel>';
        xmld = xmlt.encode('utf-8');
        doc = CreateFromDocument(xmlt);
        self.assertEqual(xmld, doc.toxml('utf-8', root_only=True))
        xmlt = '<sel><optional/></sel>';
        xmld = xmlt.encode('utf-8');
        doc = CreateFromDocument(xmlt);
        self.assertEqual(xmld, doc.toxml('utf-8', root_only=True))

    def testAbsent (self):
        xmlt = '<sel><absent/></sel>';
        xmld = xmlt.encode('utf-8');
        doc = CreateFromDocument(xmlt);
        self.assertEqual(xmld, doc.toxml('utf-8', root_only=True))
        xmlt = '<sel><absent><aContent/></absent></sel>';
        with self.assertRaises(pyxb.UnrecognizedContentError) as cm:
            doc = CreateFromDocument(xmlt);

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import logging
import pyxb.binding.generate
import pyxb.utils.domutils
import xml.dom.minidom as dom

if __name__ == '__main__':
    logging.basicConfig()
_log = logging.getLogger(__name__)

xsd = '''<?xml version="1.0" encoding="UTF-8"?>
<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema" elementFormDefault="qualified"
  targetNamespace="urn:test-issue-0094"
  xmlns:tns="urn:test-issue-0094">
  <xs:element name="MARKETPLACE">
    <xs:complexType>
      <xs:sequence>
        <xs:element name="NAME" type="xs:string"/>
      </xs:sequence>
    </xs:complexType>
  </xs:element>
  <xs:element name="MARKETPLACE_POOL">
    <xs:complexType>
        <xs:sequence maxOccurs="1" minOccurs="1">
            <xs:element ref="tns:MARKETPLACE" maxOccurs="unbounded" minOccurs="0"/>
        </xs:sequence>
    </xs:complexType>
  </xs:element>
</xs:schema>
'''

# Fully qualified XML
fqXmlSample = '''<?xml version="1.0" encoding="UTF-8"?>
<ns:MARKETPLACE_POOL xmlns:ns="urn:test-issue-0094">
  <ns:MARKETPLACE>
    <ns:NAME>OpenNebula Public</ns:NAME>
  </ns:MARKETPLACE>
</ns:MARKETPLACE_POOL>
'''

# Default-qualified XML
dqXmlSample = '''<?xml version="1.0" encoding="UTF-8"?>
<MARKETPLACE_POOL xmlns="urn:test-issue-0094">
  <MARKETPLACE>
    <NAME>OpenNebula Public</NAME>
  </MARKETPLACE>
</MARKETPLACE_POOL>
'''

# XML that lacks any namespace association
nqXmlSample = '''<?xml version="1.0" encoding="UTF-8"?>
<MARKETPLACE_POOL>
  <MARKETPLACE>
    <NAME>OpenNebula Public</NAME>
  </MARKETPLACE>
</MARKETPLACE_POOL>
'''

code = pyxb.binding.generate.GeneratePython(schema_text=xsd)
#open('code.py', 'w').write(code)
rv = compile(code, 'test', 'exec')
eval(rv)

import unittest

class TestIssue0094 (unittest.TestCase):
    def testFullyQualified (self):
        doc = CreateFromDocument(fqXmlSample);
        self.assertEqual(doc.MARKETPLACE[0].NAME, "OpenNebula Public")

    def testDefaultQualified (self):
        doc = CreateFromDocument(dqXmlSample);
        self.assertEqual(doc.MARKETPLACE[0].NAME, "OpenNebula Public")

    def testNoQualifier (self):
        with self.assertRaises(pyxb.UnrecognizedDOMRootNodeError) as cm:
            doc = CreateFromDocument(nqXmlSample)

    def testNoQualifierDefaulted (self):
        with self.assertRaises(pyxb.UnrecognizedDOMRootNodeError) as cm:
            doc = CreateFromDocument(nqXmlSample, default_namespace=Namespace)

if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
import logging
if __name__ == '__main__':
    logging.basicConfig()
_log = logging.getLogger(__name__)
import pyxb.binding.generate
import pyxb.utils.domutils
import pyxb.binding.datatypes as xs
import datetime;
from xml.dom import Node

import os.path
xsd='''<?xml version="1.0" encoding="utf-8"?>
<xs:schema elementFormDefault="qualified" xmlns:xs="http://www.w3.org/2001/XMLSchema">
  <xs:element name="b" type="xs:boolean"/>
  <xs:element name="nNI" type="xs:nonNegativeInteger"/>
  <xs:element name="int" type="xs:int"/>
  <xs:element name="time" type="xs:time"/>
  <xs:element name="duration" type="xs:duration"/>
</xs:schema>
'''

code = pyxb.binding.generate.GeneratePython(schema_text=xsd)
#open('code.py', 'w').write(code)
#print code

rv = compile(code, 'test', 'exec')
eval(rv)

from pyxb.exceptions_ import *

import unittest

class TestIssue0071 (unittest.TestCase):
    def testNonNegativeInteger (self):
        self.assertEqual(0, xs.nonNegativeInteger());
        self.assertEqual(0, CreateFromDocument(six.u('<nNI>0</nNI>')));
        self.assertRaises(SimpleTypeValueError, CreateFromDocument, six.u('<nNI/>'));

    def testBoolean (self):
        self.assertEqual(0, xs.boolean());
        self.assertEqual(0, CreateFromDocument(six.u('<b>0</b>')));
        self.assertRaises(SimpleTypeValueError, CreateFromDocument, six.u('<b/>'));

    def testInt (self):
        self.assertEqual(0, xs.int());
        self.assertEqual(0, CreateFromDocument(six.u('<int>0</int>')));
        self.assertRaises(SimpleTypeValueError, CreateFromDocument, six.u('<int/>'));

    def testTime (self):
        self.assertEqual(datetime.time(), xs.time());
        self.assertEqual(datetime.time(), CreateFromDocument(six.u('<time>00:00:00</time>')));
        self.assertRaises(SimpleTypeValueError, CreateFromDocument, six.u('<time/>'));

    def testDuration (self):
        self.assertEqual(datetime.timedelta(), xs.duration());
        self.assertEqual(datetime.timedelta(), CreateFromDocument(six.u('<duration>P0D</duration>')));
        self.assertRaises(SimpleTypeValueError, CreateFromDocument, six.u('<duration/>'));

if __name__ == '__main__':
    unittest.main()
